import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * This actor handles the paddles for the game!
 */
public class Paddle extends Actor
{
    private int yV;
    private int spd = 12;
    private int mode = 1;
    private int player = 1;
    private int location;
    private String chara;
    private int firstRun;
    private String ctrlUp;
    private String ctrlDown;
    
    /**
     * Grabs info from creator about what type of paddle this is, and sets the image accordingly. 
     */
    public Paddle(int player_, int mode_, String chara_)
    {
        player = player_;
        mode = mode_;
        chara = chara_;
        setImage("images/characters/paddle/" + chara + ".png");
    }
    
    /**
     * Determines what to do based on the specified mode, and
     * sets some important things upon first run.
     */
    public void act()
    {
        if(firstRun == 0)
        {
            if(player == 1)
            {
                ctrlUp = "w";
                ctrlDown = "s";
                location = 18;
            }
            else if(player == 2)
            {
                ctrlUp = "up";
                ctrlDown = "down";
                location = 622;
            }
            firstRun++;
        }
        checkKeypress();
        if (mode == 3)
        {
            mobileMode();
        }
        if (mode == 2)
        {
            darkSouls();
        }
        if (mode == 1)
        {
            autoMode();
        }
        if (mode == 0)
        {
            manualMode();
        }
    }
    
    /**
     * Checks if either the key listed in variables ctrlUp or ctrlDown 
     * (set by the user) are being pressed. If so, move accordingly.
     * NOTE: This function is for use with Manual Mode, AKA Mode 0.
     */
    public void checkKeypress()
    {
        if (Greenfoot.isKeyDown(ctrlUp))
        {
            yV = (-1) * spd;
        }
        else
        if (Greenfoot.isKeyDown(ctrlDown))
        {
            yV = spd;
        }
        else
        {
            yV = 0;
        }
    }
    
        
    /**
     * A mode that allows a player to directly control this paddle.
     * Moves with a speed "yV".
     * ID: 0
     */
    public void manualMode()
    {
        setLocation(location, getY() + yV);
    }
    
    /**
     * A mode, intended for practice, that sets the Y position of this paddle to
     * the Y position of the ball.
     * NOTE: As this mode is intended for practice, it is impossible to win against.
     * ID: 1
     */
    public void autoMode()
    {
        int ballY = getWorld().getObjects(Ball.class).get(0).ballY;     
        setLocation(location, ballY);
    }
    
    /**
     * A joke mode that makes this paddle as big as the screen.
     * NOTE: The paddle cannot be moved when in this mode.
     * ID: 2
     */
    public void darkSouls()
    {
        setLocation(location, 300);
        GreenfootImage image = getImage();
        image.scale(150, 1000);
        setImage(image);
    }
    
    /**
     * ~~!EXPERIMENTAL!~~
     * An mode intended for mobile devices that maps the Y position of 
     * the paddle to the Y position of the mouse.
     * ID: 3
     */
    public void mobileMode()
    {
        setLocation(location, Greenfoot.getMouseInfo().getY());
    }
}
